@@ -21,7 +21,7 @@ class Twig_Compiler
     private $source;
     private $indentation;
     private $env;
-    private $debugInfo = array();
+    private $debugInfo = [];
     private $sourceOffset;
     private $sourceLine;
     private $varNameSalt = 0;
@@ -63,7 +63,7 @@ class Twig_Compiler
     {
         $this->lastLine = null;
         $this->source = '';
-        $this->debugInfo = array();
+        $this->debugInfo = [];
         $this->sourceOffset = 0;
         // source code starts at 1 (as we then increment it when we encounter new lines)
         $this->sourceLine = 1;
@@ -142,7 +142,7 @@ class Twig_Compiler
                 setlocale(LC_NUMERIC, 'C');
             }
 
-            $this->raw($value);
+            $this->raw(var_export($value, true));
 
             if (false !== $locale) {
                 setlocale(LC_NUMERIC, $locale);
