@@ -178,7 +178,7 @@ class Twig_ExpressionParser
                     $ref = new ReflectionClass($class);
                     $negClass = 'Twig_Node_Expression_Unary_Neg';
                     $posClass = 'Twig_Node_Expression_Unary_Pos';
-                    if (!(in_array($ref->getName(), array($negClass, $posClass)) || $ref->isSubclassOf($negClass) || $ref->isSubclassOf($posClass))) {
+                    if (!(in_array($ref->getName(), [$negClass, $posClass]) || $ref->isSubclassOf($negClass) || $ref->isSubclassOf($posClass))) {
                         throw new Twig_Error_Syntax(sprintf('Unexpected unary operator "%s".', $token->getValue()), $token->getLine(), $this->parser->getStream()->getSourceContext());
                     }
 
@@ -209,7 +209,7 @@ class Twig_ExpressionParser
     {
         $stream = $this->parser->getStream();
 
-        $nodes = array();
+        $nodes = [];
         // a string cannot be followed by another string in a single expression
         $nextCanBeString = true;
         while (true) {
@@ -238,7 +238,7 @@ class Twig_ExpressionParser
         $stream = $this->parser->getStream();
         $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, '[', 'An array element was expected');
 
-        $node = new Twig_Node_Expression_Array(array(), $stream->getCurrent()->getLine());
+        $node = new Twig_Node_Expression_Array([], $stream->getCurrent()->getLine());
         $first = true;
         while (!$stream->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, ']')) {
             if (!$first) {
@@ -263,7 +263,7 @@ class Twig_ExpressionParser
         $stream = $this->parser->getStream();
         $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, '{', 'A hash element was expected');
 
-        $node = new Twig_Node_Expression_Array(array(), $stream->getCurrent()->getLine());
+        $node = new Twig_Node_Expression_Array([], $stream->getCurrent()->getLine());
         $first = true;
         while (!$stream->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, '}')) {
             if (!$first) {
@@ -352,7 +352,7 @@ class Twig_ExpressionParser
                 return new Twig_Node_Expression_GetAttr($args->getNode(0), $args->getNode(1), count($args) > 2 ? $args->getNode(2) : null, Twig_Template::ANY_CALL, $line);
             default:
                 if (null !== $alias = $this->parser->getImportedSymbol('function', $name)) {
-                    $arguments = new Twig_Node_Expression_Array(array(), $line);
+                    $arguments = new Twig_Node_Expression_Array([], $line);
                     foreach ($this->parseArguments() as $n) {
                         $arguments->addElement($n);
                     }
@@ -375,7 +375,7 @@ class Twig_ExpressionParser
         $stream = $this->parser->getStream();
         $token = $stream->next();
         $lineno = $token->getLine();
-        $arguments = new Twig_Node_Expression_Array(array(), $lineno);
+        $arguments = new Twig_Node_Expression_Array([], $lineno);
         $type = Twig_Template::ANY_CALL;
         if ('.' == $token->getValue()) {
             $token = $stream->next();
@@ -434,7 +434,7 @@ class Twig_ExpressionParser
                 }
 
                 $class = $this->getFilterNodeClass('slice', $token->getLine());
-                $arguments = new Twig_Node(array($arg, $length));
+                $arguments = new Twig_Node([$arg, $length]);
                 $filter = new $class($node, new Twig_Node_Expression_Constant('slice', $token->getLine()), $arguments, $token->getLine());
 
                 $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, ']');
@@ -493,7 +493,7 @@ class Twig_ExpressionParser
      */
     public function parseArguments($namedArguments = false, $definition = false)
     {
-        $args = array();
+        $args = [];
         $stream = $this->parser->getStream();
 
         $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, '(', 'A list of arguments must begin with an opening parenthesis');
@@ -549,11 +549,11 @@ class Twig_ExpressionParser
     public function parseAssignmentExpression()
     {
         $stream = $this->parser->getStream();
-        $targets = array();
+        $targets = [];
         while (true) {
             $token = $stream->expect(/* Twig_Token::NAME_TYPE */ 5, null, 'Only variables can be assigned to');
             $value = $token->getValue();
-            if (in_array(strtolower($value), array('true', 'false', 'none', 'null'))) {
+            if (in_array(strtolower($value), ['true', 'false', 'none', 'null'])) {
                 throw new Twig_Error_Syntax(sprintf('You cannot assign a value to "%s".', $value), $token->getLine(), $stream->getSourceContext());
             }
             $targets[] = new Twig_Node_Expression_AssignName($value, $token->getLine());
@@ -568,7 +568,7 @@ class Twig_ExpressionParser
 
     public function parseMultitargetExpression()
     {
-        $targets = array();
+        $targets = [];
         while (true) {
             $targets[] = $this->parseExpression();
             if (!$this->parser->getStream()->nextIf(/* Twig_Token::PUNCTUATION_TYPE */ 9, ',')) {
@@ -604,7 +604,7 @@ class Twig_ExpressionParser
         $name = $stream->expect(/* Twig_Token::NAME_TYPE */ 5)->getValue();
 
         if ($test = $this->env->getTest($name)) {
-            return array($name, $test);
+            return [$name, $test];
         }
 
         if ($stream->test(/* Twig_Token::NAME_TYPE */ 5)) {
@@ -614,7 +614,7 @@ class Twig_ExpressionParser
             if ($test = $this->env->getTest($name)) {
                 $stream->next();
 
-                return array($name, $test);
+                return [$name, $test];
             }
         }
 
