@@ -11,10 +11,10 @@
 
 final class Twig_Extension_Core extends Twig_Extension
 {
-    private $dateFormats = array('F j, Y H:i', '%d days');
-    private $numberFormat = array(0, '.', ',');
+    private $dateFormats = ['F j, Y H:i', '%d days'];
+    private $numberFormat = [0, '.', ','];
     private $timezone = null;
-    private $escapers = array();
+    private $escapers = [];
 
     /**
      * Defines a new escaper to be used via the escape filter.
@@ -97,7 +97,7 @@ final class Twig_Extension_Core extends Twig_Extension
      */
     public function setNumberFormat($decimal, $decimalPoint, $thousandSep)
     {
-        $this->numberFormat = array($decimal, $decimalPoint, $thousandSep);
+        $this->numberFormat = [$decimal, $decimalPoint, $thousandSep];
     }
 
     /**
@@ -112,7 +112,7 @@ final class Twig_Extension_Core extends Twig_Extension
 
     public function getTokenParsers()
     {
-        return array(
+        return [
             new Twig_TokenParser_For(),
             new Twig_TokenParser_If(),
             new Twig_TokenParser_Extends(),
@@ -130,18 +130,18 @@ final class Twig_Extension_Core extends Twig_Extension
             new Twig_TokenParser_Embed(),
             new Twig_TokenParser_With(),
             new Twig_TokenParser_Deprecated(),
-        );
+        ];
     }
 
     public function getFilters()
     {
-        return array(
+        return [
             // formatting filters
-            new Twig_Filter('date', 'twig_date_format_filter', array('needs_environment' => true)),
-            new Twig_Filter('date_modify', 'twig_date_modify_filter', array('needs_environment' => true)),
+            new Twig_Filter('date', 'twig_date_format_filter', ['needs_environment' => true]),
+            new Twig_Filter('date_modify', 'twig_date_modify_filter', ['needs_environment' => true]),
             new Twig_Filter('format', 'sprintf'),
             new Twig_Filter('replace', 'twig_replace_filter'),
-            new Twig_Filter('number_format', 'twig_number_format_filter', array('needs_environment' => true)),
+            new Twig_Filter('number_format', 'twig_number_format_filter', ['needs_environment' => true]),
             new Twig_Filter('abs', 'abs'),
             new Twig_Filter('round', 'twig_round'),
 
@@ -151,108 +151,108 @@ final class Twig_Extension_Core extends Twig_Extension
             new Twig_Filter('convert_encoding', 'twig_convert_encoding'),
 
             // string filters
-            new Twig_Filter('title', 'twig_title_string_filter', array('needs_environment' => true)),
-            new Twig_Filter('capitalize', 'twig_capitalize_string_filter', array('needs_environment' => true)),
-            new Twig_Filter('upper', 'twig_upper_filter', array('needs_environment' => true)),
-            new Twig_Filter('lower', 'twig_lower_filter', array('needs_environment' => true)),
+            new Twig_Filter('title', 'twig_title_string_filter', ['needs_environment' => true]),
+            new Twig_Filter('capitalize', 'twig_capitalize_string_filter', ['needs_environment' => true]),
+            new Twig_Filter('upper', 'twig_upper_filter', ['needs_environment' => true]),
+            new Twig_Filter('lower', 'twig_lower_filter', ['needs_environment' => true]),
             new Twig_Filter('striptags', 'strip_tags'),
             new Twig_Filter('trim', 'twig_trim_filter'),
-            new Twig_Filter('nl2br', 'nl2br', array('pre_escape' => 'html', 'is_safe' => array('html'))),
+            new Twig_Filter('nl2br', 'nl2br', ['pre_escape' => 'html', 'is_safe' => ['html']]),
 
             // array helpers
             new Twig_Filter('join', 'twig_join_filter'),
-            new Twig_Filter('split', 'twig_split_filter', array('needs_environment' => true)),
+            new Twig_Filter('split', 'twig_split_filter', ['needs_environment' => true]),
             new Twig_Filter('sort', 'twig_sort_filter'),
             new Twig_Filter('merge', 'twig_array_merge'),
             new Twig_Filter('batch', 'twig_array_batch'),
 
             // string/array filters
-            new Twig_Filter('reverse', 'twig_reverse_filter', array('needs_environment' => true)),
-            new Twig_Filter('length', 'twig_length_filter', array('needs_environment' => true)),
-            new Twig_Filter('slice', 'twig_slice', array('needs_environment' => true)),
-            new Twig_Filter('first', 'twig_first', array('needs_environment' => true)),
-            new Twig_Filter('last', 'twig_last', array('needs_environment' => true)),
+            new Twig_Filter('reverse', 'twig_reverse_filter', ['needs_environment' => true]),
+            new Twig_Filter('length', 'twig_length_filter', ['needs_environment' => true]),
+            new Twig_Filter('slice', 'twig_slice', ['needs_environment' => true]),
+            new Twig_Filter('first', 'twig_first', ['needs_environment' => true]),
+            new Twig_Filter('last', 'twig_last', ['needs_environment' => true]),
 
             // iteration and runtime
-            new Twig_Filter('default', '_twig_default_filter', array('node_class' => 'Twig_Node_Expression_Filter_Default')),
+            new Twig_Filter('default', '_twig_default_filter', ['node_class' => 'Twig_Node_Expression_Filter_Default']),
             new Twig_Filter('keys', 'twig_get_array_keys_filter'),
 
             // escaping
-            new Twig_Filter('escape', 'twig_escape_filter', array('needs_environment' => true, 'is_safe_callback' => 'twig_escape_filter_is_safe')),
-            new Twig_Filter('e', 'twig_escape_filter', array('needs_environment' => true, 'is_safe_callback' => 'twig_escape_filter_is_safe')),
-        );
+            new Twig_Filter('escape', 'twig_escape_filter', ['needs_environment' => true, 'is_safe_callback' => 'twig_escape_filter_is_safe']),
+            new Twig_Filter('e', 'twig_escape_filter', ['needs_environment' => true, 'is_safe_callback' => 'twig_escape_filter_is_safe']),
+        ];
     }
 
     public function getFunctions()
     {
-        return array(
+        return [
             new Twig_Function('max', 'max'),
             new Twig_Function('min', 'min'),
             new Twig_Function('range', 'range'),
             new Twig_Function('constant', 'twig_constant'),
             new Twig_Function('cycle', 'twig_cycle'),
-            new Twig_Function('random', 'twig_random', array('needs_environment' => true)),
-            new Twig_Function('date', 'twig_date_converter', array('needs_environment' => true)),
-            new Twig_Function('include', 'twig_include', array('needs_environment' => true, 'needs_context' => true, 'is_safe' => array('all'))),
-            new Twig_Function('source', 'twig_source', array('needs_environment' => true, 'is_safe' => array('all'))),
-        );
+            new Twig_Function('random', 'twig_random', ['needs_environment' => true]),
+            new Twig_Function('date', 'twig_date_converter', ['needs_environment' => true]),
+            new Twig_Function('include', 'twig_include', ['needs_environment' => true, 'needs_context' => true, 'is_safe' => ['all']]),
+            new Twig_Function('source', 'twig_source', ['needs_environment' => true, 'is_safe' => ['all']]),
+        ];
     }
 
     public function getTests()
     {
-        return array(
-            new Twig_Test('even', null, array('node_class' => 'Twig_Node_Expression_Test_Even')),
-            new Twig_Test('odd', null, array('node_class' => 'Twig_Node_Expression_Test_Odd')),
-            new Twig_Test('defined', null, array('node_class' => 'Twig_Node_Expression_Test_Defined')),
-            new Twig_Test('same as', null, array('node_class' => 'Twig_Node_Expression_Test_Sameas')),
-            new Twig_Test('none', null, array('node_class' => 'Twig_Node_Expression_Test_Null')),
-            new Twig_Test('null', null, array('node_class' => 'Twig_Node_Expression_Test_Null')),
-            new Twig_Test('divisible by', null, array('node_class' => 'Twig_Node_Expression_Test_Divisibleby')),
-            new Twig_Test('constant', null, array('node_class' => 'Twig_Node_Expression_Test_Constant')),
+        return [
+            new Twig_Test('even', null, ['node_class' => 'Twig_Node_Expression_Test_Even']),
+            new Twig_Test('odd', null, ['node_class' => 'Twig_Node_Expression_Test_Odd']),
+            new Twig_Test('defined', null, ['node_class' => 'Twig_Node_Expression_Test_Defined']),
+            new Twig_Test('same as', null, ['node_class' => 'Twig_Node_Expression_Test_Sameas']),
+            new Twig_Test('none', null, ['node_class' => 'Twig_Node_Expression_Test_Null']),
+            new Twig_Test('null', null, ['node_class' => 'Twig_Node_Expression_Test_Null']),
+            new Twig_Test('divisible by', null, ['node_class' => 'Twig_Node_Expression_Test_Divisibleby']),
+            new Twig_Test('constant', null, ['node_class' => 'Twig_Node_Expression_Test_Constant']),
             new Twig_Test('empty', 'twig_test_empty'),
             new Twig_Test('iterable', 'twig_test_iterable'),
-        );
+        ];
     }
 
     public function getOperators()
     {
-        return array(
-            array(
-                'not' => array('precedence' => 50, 'class' => 'Twig_Node_Expression_Unary_Not'),
-                '-' => array('precedence' => 500, 'class' => 'Twig_Node_Expression_Unary_Neg'),
-                '+' => array('precedence' => 500, 'class' => 'Twig_Node_Expression_Unary_Pos'),
-            ),
-            array(
-                'or' => array('precedence' => 10, 'class' => 'Twig_Node_Expression_Binary_Or', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                'and' => array('precedence' => 15, 'class' => 'Twig_Node_Expression_Binary_And', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                'b-or' => array('precedence' => 16, 'class' => 'Twig_Node_Expression_Binary_BitwiseOr', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                'b-xor' => array('precedence' => 17, 'class' => 'Twig_Node_Expression_Binary_BitwiseXor', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                'b-and' => array('precedence' => 18, 'class' => 'Twig_Node_Expression_Binary_BitwiseAnd', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                '==' => array('precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_Equal', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                '!=' => array('precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_NotEqual', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                '<' => array('precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_Less', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                '>' => array('precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_Greater', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                '>=' => array('precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_GreaterEqual', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                '<=' => array('precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_LessEqual', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                'not in' => array('precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_NotIn', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                'in' => array('precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_In', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                'matches' => array('precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_Matches', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                'starts with' => array('precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_StartsWith', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                'ends with' => array('precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_EndsWith', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                '..' => array('precedence' => 25, 'class' => 'Twig_Node_Expression_Binary_Range', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                '+' => array('precedence' => 30, 'class' => 'Twig_Node_Expression_Binary_Add', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                '-' => array('precedence' => 30, 'class' => 'Twig_Node_Expression_Binary_Sub', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                '~' => array('precedence' => 40, 'class' => 'Twig_Node_Expression_Binary_Concat', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                '*' => array('precedence' => 60, 'class' => 'Twig_Node_Expression_Binary_Mul', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                '/' => array('precedence' => 60, 'class' => 'Twig_Node_Expression_Binary_Div', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                '//' => array('precedence' => 60, 'class' => 'Twig_Node_Expression_Binary_FloorDiv', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                '%' => array('precedence' => 60, 'class' => 'Twig_Node_Expression_Binary_Mod', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                'is' => array('precedence' => 100, 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                'is not' => array('precedence' => 100, 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT),
-                '**' => array('precedence' => 200, 'class' => 'Twig_Node_Expression_Binary_Power', 'associativity' => Twig_ExpressionParser::OPERATOR_RIGHT),
-                '??' => array('precedence' => 300, 'class' => 'Twig_Node_Expression_NullCoalesce', 'associativity' => Twig_ExpressionParser::OPERATOR_RIGHT),
-            ),
-        );
+        return [
+            [
+                'not' => ['precedence' => 50, 'class' => 'Twig_Node_Expression_Unary_Not'],
+                '-' => ['precedence' => 500, 'class' => 'Twig_Node_Expression_Unary_Neg'],
+                '+' => ['precedence' => 500, 'class' => 'Twig_Node_Expression_Unary_Pos'],
+            ],
+            [
+                'or' => ['precedence' => 10, 'class' => 'Twig_Node_Expression_Binary_Or', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                'and' => ['precedence' => 15, 'class' => 'Twig_Node_Expression_Binary_And', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                'b-or' => ['precedence' => 16, 'class' => 'Twig_Node_Expression_Binary_BitwiseOr', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                'b-xor' => ['precedence' => 17, 'class' => 'Twig_Node_Expression_Binary_BitwiseXor', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                'b-and' => ['precedence' => 18, 'class' => 'Twig_Node_Expression_Binary_BitwiseAnd', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                '==' => ['precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_Equal', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                '!=' => ['precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_NotEqual', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                '<' => ['precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_Less', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                '>' => ['precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_Greater', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                '>=' => ['precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_GreaterEqual', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                '<=' => ['precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_LessEqual', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                'not in' => ['precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_NotIn', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                'in' => ['precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_In', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                'matches' => ['precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_Matches', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                'starts with' => ['precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_StartsWith', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                'ends with' => ['precedence' => 20, 'class' => 'Twig_Node_Expression_Binary_EndsWith', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                '..' => ['precedence' => 25, 'class' => 'Twig_Node_Expression_Binary_Range', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                '+' => ['precedence' => 30, 'class' => 'Twig_Node_Expression_Binary_Add', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                '-' => ['precedence' => 30, 'class' => 'Twig_Node_Expression_Binary_Sub', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                '~' => ['precedence' => 40, 'class' => 'Twig_Node_Expression_Binary_Concat', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                '*' => ['precedence' => 60, 'class' => 'Twig_Node_Expression_Binary_Mul', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                '/' => ['precedence' => 60, 'class' => 'Twig_Node_Expression_Binary_Div', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                '//' => ['precedence' => 60, 'class' => 'Twig_Node_Expression_Binary_FloorDiv', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                '%' => ['precedence' => 60, 'class' => 'Twig_Node_Expression_Binary_Mod', 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                'is' => ['precedence' => 100, 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                'is not' => ['precedence' => 100, 'associativity' => Twig_ExpressionParser::OPERATOR_LEFT],
+                '**' => ['precedence' => 200, 'class' => 'Twig_Node_Expression_Binary_Power', 'associativity' => Twig_ExpressionParser::OPERATOR_RIGHT],
+                '??' => ['precedence' => 300, 'class' => 'Twig_Node_Expression_NullCoalesce', 'associativity' => Twig_ExpressionParser::OPERATOR_RIGHT],
+            ],
+        ];
     }
 }
 
@@ -341,7 +341,7 @@ function twig_random(Twig_Environment $env, $values = null)
  * @param Twig_Environment                      $env
  * @param DateTimeInterface|DateInterval|string $date     A date
  * @param string|null                           $format   The target format, null to use the default
- * @param DateTimeZone|string|null|false        $timezone The target timezone, null to use the default, false to leave unchanged
+ * @param DateTimeZone|string|false|null        $timezone The target timezone, null to use the default, false to leave unchanged
  *
  * @return string The formatted date
  */
@@ -390,7 +390,7 @@ function twig_date_modify_filter(Twig_Environment $env, $date, $modifier)
  *
  * @param Twig_Environment               $env
  * @param DateTimeInterface|string|null  $date     A date or null to use the current time
- * @param DateTimeZone|string|null|false $timezone The target timezone, null to use the default, false to leave unchanged
+ * @param DateTimeZone|string|false|null $timezone The target timezone, null to use the default, false to leave unchanged
  *
  * @return DateTime A DateTime instance
  */
@@ -582,7 +582,7 @@ function twig_slice(Twig_Environment $env, $item, $start, $length = null, $prese
             try {
                 return iterator_to_array(new LimitIterator($item, $start, null === $length ? -1 : $length), $preserveKeys);
             } catch (OutOfBoundsException $exception) {
-                return array();
+                return [];
             }
         }
 
@@ -631,9 +631,12 @@ function twig_last(Twig_Environment $env, $item)
 /**
  * Joins the values to a string.
  *
- * The separator between elements is an empty string per default, you can define it with the optional parameter.
+ * The separators between elements are empty strings per default, you can define them with the optional parameters.
  *
  * <pre>
+ *  {{ [1, 2, 3]|join(', ', ' and ') }}
+ *  {# returns 1, 2 and 3 #}
+ *
  *  {{ [1, 2, 3]|join('|') }}
  *  {# returns 1|2|3 #}
  *
@@ -641,18 +644,34 @@ function twig_last(Twig_Environment $env, $item)
  *  {# returns 123 #}
  * </pre>
  *
- * @param array  $value An array
- * @param string $glue  The separator
+ * @param array       $value An array
+ * @param string      $glue  The separator
+ * @param string|null $and   The separator for the last pair
  *
  * @return string The concatenated string
  */
-function twig_join_filter($value, $glue = '')
+function twig_join_filter($value, $glue = '', $and = null)
 {
     if ($value instanceof Traversable) {
         $value = iterator_to_array($value, false);
+    } else {
+        $value = (array) $value;
     }
 
-    return implode($glue, (array) $value);
+    if (0 === count($value)) {
+        return '';
+    }
+
+    if (null === $and || $and === $glue) {
+        return implode($glue, $value);
+    }
+
+    $v = array_values($value);
+    if (1 === count($v)) {
+        return $v[0];
+    }
+
+    return implode($glue, array_slice($value, 0, -1)).$and.$v[count($v) - 1];
 }
 
 /**
@@ -691,10 +710,10 @@ function twig_split_filter(Twig_Environment $env, $value, $delimiter, $limit = n
 
     $length = mb_strlen($value, $env->getCharset());
     if ($length < $limit) {
-        return array($value);
+        return [$value];
     }
 
-    $r = array();
+    $r = [];
     for ($i = 0; $i < $length; $i += $limit) {
         $r[] = mb_substr($value, $i, $limit, $env->getCharset());
     }
@@ -740,7 +759,7 @@ function twig_get_array_keys_filter($array)
         }
 
         if ($array instanceof Iterator) {
-            $keys = array();
+            $keys = [];
             $array->rewind();
             while ($array->valid()) {
                 $keys[] = $array->key();
@@ -750,7 +769,7 @@ function twig_get_array_keys_filter($array)
             return $keys;
         }
 
-        $keys = array();
+        $keys = [];
         foreach ($array as $key => $item) {
             $keys[] = $key;
         }
@@ -759,7 +778,7 @@ function twig_get_array_keys_filter($array)
     }
 
     if (!is_array($array)) {
-        return array();
+        return [];
     }
 
     return array_keys($array);
@@ -898,7 +917,7 @@ function twig_escape_filter(Twig_Environment $env, $string, $strategy = 'html',
     if (!is_string($string)) {
         if (is_object($string) && method_exists($string, '__toString')) {
             $string = (string) $string;
-        } elseif (in_array($strategy, array('html', 'js', 'css', 'html_attr', 'url'))) {
+        } elseif (in_array($strategy, ['html', 'js', 'css', 'html_attr', 'url'])) {
             return $string;
         }
     }
@@ -918,7 +937,7 @@ function twig_escape_filter(Twig_Environment $env, $string, $strategy = 'html',
             // Using a static variable to avoid initializing the array
             // each time the function is called. Moving the declaration on the
             // top of the function slow downs other escaping strategies.
-            static $htmlspecialcharsCharsets = array(
+            static $htmlspecialcharsCharsets = [
                 'ISO-8859-1' => true, 'ISO8859-1' => true,
                 'ISO-8859-15' => true, 'ISO8859-15' => true,
                 'utf-8' => true, 'UTF-8' => true,
@@ -933,7 +952,7 @@ function twig_escape_filter(Twig_Environment $env, $string, $strategy = 'html',
                 'SHIFT_JIS' => true, 'SJIS' => true, '932' => true,
                 'EUC-JP' => true, 'EUCJP' => true,
                 'ISO8859-5' => true, 'ISO-8859-5' => true, 'MACROMAN' => true,
-            );
+            ];
 
             if (isset($htmlspecialcharsCharsets[$charset])) {
                 return htmlspecialchars($string, ENT_QUOTES | ENT_SUBSTITUTE, $charset);
@@ -970,7 +989,7 @@ function twig_escape_filter(Twig_Environment $env, $string, $strategy = 'html',
                  * Escape sequences supported only by JavaScript, not JSON, are ommitted.
                  * \" is also supported but omitted, because the resulting string is not HTML safe.
                  */
-                static $shortMap = array(
+                static $shortMap = [
                     '\\' => '\\\\',
                     '/' => '\\/',
                     "\x08" => '\b',
@@ -978,7 +997,7 @@ function twig_escape_filter(Twig_Environment $env, $string, $strategy = 'html',
                     "\x0A" => '\n',
                     "\x0D" => '\r',
                     "\x09" => '\t',
-                );
+                ];
 
                 if (isset($shortMap[$char])) {
                     return $shortMap[$char];
@@ -1038,7 +1057,6 @@ function twig_escape_filter(Twig_Environment $env, $string, $strategy = 'html',
                  * @copyright Copyright (c) 2005-2012 Zend Technologies USA Inc. (https://www.zend.com)
                  * @license   https://framework.zend.com/license/new-bsd New BSD License
                  */
-
                 $chr = $matches[0];
                 $ord = ord($chr);
 
@@ -1061,12 +1079,12 @@ function twig_escape_filter(Twig_Environment $env, $string, $strategy = 'html',
                      * entities that XML supports. Using HTML entities would result in this error:
                      *     XML Parsing Error: undefined entity
                      */
-                    static $entityMap = array(
+                    static $entityMap = [
                         34 => '&quot;', /* quotation mark */
                         38 => '&amp;',  /* ampersand */
                         60 => '&lt;',   /* less-than sign */
                         62 => '&gt;',   /* greater-than sign */
-                    );
+                    ];
 
                     if (isset($entityMap[$ord])) {
                         return $entityMap[$ord];
@@ -1102,7 +1120,7 @@ function twig_escape_filter(Twig_Environment $env, $string, $strategy = 'html',
                 return $escapers[$strategy]($env, $string, $charset);
             }
 
-            $validStrategies = implode(', ', array_merge(array('html', 'js', 'url', 'css', 'html_attr'), array_keys($escapers)));
+            $validStrategies = implode(', ', array_merge(['html', 'js', 'url', 'css', 'html_attr'], array_keys($escapers)));
 
             throw new Twig_Error_Runtime(sprintf('Invalid escaping strategy "%s" (valid ones: %s).', $strategy, $validStrategies));
     }
@@ -1115,13 +1133,13 @@ function twig_escape_filter_is_safe(Twig_Node $filterArgs)
 {
     foreach ($filterArgs as $arg) {
         if ($arg instanceof Twig_Node_Expression_Constant) {
-            return array($arg->getAttribute('value'));
+            return [$arg->getAttribute('value')];
         }
 
-        return array();
+        return [];
     }
 
-    return array('html');
+    return ['html'];
 }
 
 function twig_convert_encoding($string, $to, $from)
@@ -1233,7 +1251,7 @@ function twig_ensure_traversable($seq)
         return $seq;
     }
 
-    return array();
+    return [];
 }
 
 /**
@@ -1260,7 +1278,7 @@ function twig_test_empty($value)
         return '' === (string) $value;
     }
 
-    return '' === $value || false === $value || null === $value || array() === $value;
+    return '' === $value || false === $value || null === $value || [] === $value;
 }
 
 /**
@@ -1295,7 +1313,7 @@ function twig_test_iterable($value)
  *
  * @return string The rendered template
  */
-function twig_include(Twig_Environment $env, $context, $template, $variables = array(), $withContext = true, $ignoreMissing = false, $sandboxed = false)
+function twig_include(Twig_Environment $env, $context, $template, $variables = [], $withContext = true, $ignoreMissing = false, $sandboxed = false)
 {
     $alreadySandboxed = false;
     $sandbox = null;
@@ -1361,7 +1379,7 @@ function twig_source(Twig_Environment $env, $name, $ignoreMissing = false)
  * Provides the ability to get constants from instances as well as class/global constants.
  *
  * @param string      $constant The name of the constant
- * @param null|object $object   The object to get the constant from
+ * @param object|null $object   The object to get the constant from
  *
  * @return string
  */
@@ -1378,7 +1396,7 @@ function twig_constant($constant, $object = null)
  * Checks if a constant exists.
  *
  * @param string      $constant The name of the constant
- * @param null|object $object   The object to get the constant from
+ * @param object|null $object   The object to get the constant from
  *
  * @return bool
  */
@@ -1439,13 +1457,13 @@ function twig_array_batch($items, $size, $fill = null)
  *
  * @internal
  */
-function twig_get_attribute(Twig_Environment $env, Twig_Source $source, $object, $item, array $arguments = array(), $type = /* Twig_Template::ANY_CALL */ 'any', $isDefinedTest = false, $ignoreStrictCheck = false, $sandboxed = false)
+function twig_get_attribute(Twig_Environment $env, Twig_Source $source, $object, $item, array $arguments = [], $type = /* Twig_Template::ANY_CALL */ 'any', $isDefinedTest = false, $ignoreStrictCheck = false, $sandboxed = false)
 {
     // array
     if (/* Twig_Template::METHOD_CALL */ 'method' !== $type) {
         $arrayItem = is_bool($item) || is_float($item) ? (int) $item : $item;
 
-        if ((is_array($object) && (isset($object[$arrayItem]) || array_key_exists($arrayItem, $object)))
+        if (((is_array($object) || $object instanceof ArrayObject) && (isset($object[$arrayItem]) || array_key_exists($arrayItem, $object)))
             || ($object instanceof ArrayAccess && isset($object[$arrayItem]))
         ) {
             if ($isDefinedTest) {
@@ -1529,7 +1547,7 @@ function twig_get_attribute(Twig_Environment $env, Twig_Source $source, $object,
         }
     }
 
-    static $cache = array();
+    static $cache = [];
 
     $class = get_class($object);
 
@@ -1539,7 +1557,7 @@ function twig_get_attribute(Twig_Environment $env, Twig_Source $source, $object,
         $methods = get_class_methods($object);
         sort($methods);
         $lcMethods = array_map('strtolower', $methods);
-        $classCache = array();
+        $classCache = [];
         foreach ($methods as $i => $method) {
             $classCache[$method] = $method;
             $classCache[$lcName = $lcMethods[$i]] = $method;
