@@ -25,19 +25,19 @@ final class Twig_Extension_Escaper extends Twig_Extension
 
     public function getTokenParsers()
     {
-        return array(new Twig_TokenParser_AutoEscape());
+        return [new Twig_TokenParser_AutoEscape()];
     }
 
     public function getNodeVisitors()
     {
-        return array(new Twig_NodeVisitor_Escaper());
+        return [new Twig_NodeVisitor_Escaper()];
     }
 
     public function getFilters()
     {
-        return array(
-            new Twig_Filter('raw', 'twig_raw_filter', array('is_safe' => array('all'))),
-        );
+        return [
+            new Twig_Filter('raw', 'twig_raw_filter', ['is_safe' => ['all']]),
+        ];
     }
 
     /**
@@ -51,7 +51,7 @@ final class Twig_Extension_Escaper extends Twig_Extension
     public function setDefaultStrategy($defaultStrategy)
     {
         if ('name' === $defaultStrategy) {
-            $defaultStrategy = array('Twig_FileExtensionEscapingStrategy', 'guess');
+            $defaultStrategy = ['Twig_FileExtensionEscapingStrategy', 'guess'];
         }
 
         $this->defaultStrategy = $defaultStrategy;
