@@ -28,8 +28,8 @@ final class Twig_ExtensionSet
     private $unaryOperators;
     private $binaryOperators;
     private $globals;
-    private $functionCallbacks = array();
-    private $filterCallbacks = array();
+    private $functionCallbacks = [];
+    private $filterCallbacks = [];
     private $lastModified = 0;
 
     public function __construct()
@@ -330,7 +330,7 @@ final class Twig_ExtensionSet
             return $this->globals;
         }
 
-        $globals = array();
+        $globals = [];
         foreach ($this->extensions as $extension) {
             if (!$extension instanceof Twig_Extension_GlobalsInterface) {
                 continue;
@@ -386,6 +386,19 @@ final class Twig_ExtensionSet
             return $this->tests[$name];
         }
 
+        foreach ($this->tests as $pattern => $test) {
+            $pattern = str_replace('\\*', '(.*?)', preg_quote($pattern, '#'), $count);
+
+            if ($count) {
+                if (preg_match('#^'.$pattern.'$#', $name, $matches)) {
+                    array_shift($matches);
+                    $test->setArguments($matches);
+
+                    return $test;
+                }
+            }
+        }
+
         return false;
     }
 
@@ -419,13 +432,13 @@ final class Twig_ExtensionSet
 
     private function initExtensions()
     {
-        $this->parsers = array();
-        $this->filters = array();
-        $this->functions = array();
-        $this->tests = array();
-        $this->visitors = array();
-        $this->unaryOperators = array();
-        $this->binaryOperators = array();
+        $this->parsers = [];
+        $this->filters = [];
+        $this->functions = [];
+        $this->tests = [];
+        $this->visitors = [];
+        $this->unaryOperators = [];
+        $this->binaryOperators = [];
 
         foreach ($this->extensions as $extension) {
             $this->initExtension($extension);
