@@ -19,14 +19,14 @@ class Twig_Node_Block extends Twig_Node
 {
     public function __construct($name, Twig_Node $body, $lineno, $tag = null)
     {
-        parent::__construct(array('body' => $body), array('name' => $name), $lineno, $tag);
+        parent::__construct(['body' => $body], ['name' => $name], $lineno, $tag);
     }
 
     public function compile(Twig_Compiler $compiler)
     {
         $compiler
             ->addDebugInfo($this)
-            ->write(sprintf("public function block_%s(\$context, array \$blocks = array())\n", $this->getAttribute('name')), "{\n")
+            ->write(sprintf("public function block_%s(\$context, array \$blocks = [])\n", $this->getAttribute('name')), "{\n")
             ->indent()
         ;
 
