@@ -3,17 +3,17 @@
 /*
  * This file is part of Twig.
  *
- * (c) 2009 Fabien Potencier
- * (c) 2009 Armin Ronacher
+ * (c) Fabien Potencier
+ * (c) Armin Ronacher
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
 abstract class Twig_Node_Expression_Binary extends Twig_Node_Expression
 {
-    public function __construct(Twig_NodeInterface $left, Twig_NodeInterface $right, $lineno)
+    public function __construct(Twig_Node $left, Twig_Node $right, $lineno)
     {
-        parent::__construct(array('left' => $left, 'right' => $right), array(), $lineno);
+        parent::__construct(['left' => $left, 'right' => $right], [], $lineno);
     }
 
     public function compile(Twig_Compiler $compiler)
@@ -33,3 +33,5 @@ abstract class Twig_Node_Expression_Binary extends Twig_Node_Expression
 
     abstract public function operator(Twig_Compiler $compiler);
 }
+
+class_alias('Twig_Node_Expression_Binary', 'Twig\Node\Expression\Binary\AbstractBinary', false);
