@@ -13,7 +13,7 @@ abstract class Twig_Node_Expression_Unary extends Twig_Node_Expression
 {
     public function __construct(Twig_Node $node, $lineno)
     {
-        parent::__construct(array('node' => $node), array(), $lineno);
+        parent::__construct(['node' => $node], [], $lineno);
     }
 
     public function compile(Twig_Compiler $compiler)
