@@ -19,12 +19,12 @@ class Twig_Node_If extends Twig_Node
 {
     public function __construct(Twig_Node $tests, Twig_Node $else = null, $lineno, $tag = null)
     {
-        $nodes = array('tests' => $tests);
+        $nodes = ['tests' => $tests];
         if (null !== $else) {
             $nodes['else'] = $else;
         }
 
-        parent::__construct($nodes, array(), $lineno, $tag);
+        parent::__construct($nodes, [], $lineno, $tag);
     }
 
     public function compile(Twig_Compiler $compiler)
