@@ -26,7 +26,7 @@ class Twig_Node_Macro extends Twig_Node
             }
         }
 
-        parent::__construct(array('body' => $body, 'arguments' => $arguments), array('name' => $name), $lineno, $tag);
+        parent::__construct(['body' => $body, 'arguments' => $arguments], ['name' => $name], $lineno, $tag);
     }
 
     public function compile(Twig_Compiler $compiler)
@@ -61,7 +61,7 @@ class Twig_Node_Macro extends Twig_Node
         ;
 
         $compiler
-            ->write("\$context = \$this->env->mergeGlobals(array(\n")
+            ->write("\$context = \$this->env->mergeGlobals([\n")
             ->indent()
         ;
 
@@ -83,8 +83,8 @@ class Twig_Node_Macro extends Twig_Node
         $compiler
             ->raw("\$__varargs__,\n")
             ->outdent()
-            ->write("));\n\n")
-            ->write("\$blocks = array();\n\n")
+            ->write("]);\n\n")
+            ->write("\$blocks = [];\n\n")
             ->write("ob_start();\n")
             ->write("try {\n")
             ->indent()
