@@ -11,8 +11,8 @@
 
 final class Twig_NodeVisitor_SafeAnalysis extends Twig_BaseNodeVisitor
 {
-    private $data = array();
-    private $safeVars = array();
+    private $data = [];
+    private $safeVars = [];
 
     public function setSafeVars($safeVars)
     {
@@ -51,10 +51,10 @@ final class Twig_NodeVisitor_SafeAnalysis extends Twig_BaseNodeVisitor
                 }
             }
         }
-        $this->data[$hash][] = array(
+        $this->data[$hash][] = [
             'key' => $node,
             'value' => $safe,
-        );
+        ];
     }
 
     protected function doEnterNode(Twig_Node $node, Twig_Environment $env)
@@ -66,13 +66,13 @@ final class Twig_NodeVisitor_SafeAnalysis extends Twig_BaseNodeVisitor
     {
         if ($node instanceof Twig_Node_Expression_Constant) {
             // constants are marked safe for all
-            $this->setSafe($node, array('all'));
+            $this->setSafe($node, ['all']);
         } elseif ($node instanceof Twig_Node_Expression_BlockReference) {
             // blocks are safe by definition
-            $this->setSafe($node, array('all'));
+            $this->setSafe($node, ['all']);
         } elseif ($node instanceof Twig_Node_Expression_Parent) {
             // parent block is safe by definition
-            $this->setSafe($node, array('all'));
+            $this->setSafe($node, ['all']);
         } elseif ($node instanceof Twig_Node_Expression_Conditional) {
             // intersect safeness of both operands
             $safe = $this->intersectSafe($this->getSafe($node->getNode('expr2')), $this->getSafe($node->getNode('expr3')));
@@ -88,7 +88,7 @@ final class Twig_NodeVisitor_SafeAnalysis extends Twig_BaseNodeVisitor
                 }
                 $this->setSafe($node, $safe);
             } else {
-                $this->setSafe($node, array());
+                $this->setSafe($node, []);
             }
         } elseif ($node instanceof Twig_Node_Expression_Function) {
             // function expression is safe when the function is safe
@@ -98,23 +98,23 @@ final class Twig_NodeVisitor_SafeAnalysis extends Twig_BaseNodeVisitor
             if (false !== $function) {
                 $this->setSafe($node, $function->getSafe($args));
             } else {
-                $this->setSafe($node, array());
+                $this->setSafe($node, []);
             }
         } elseif ($node instanceof Twig_Node_Expression_MethodCall) {
             if ($node->getAttribute('safe')) {
-                $this->setSafe($node, array('all'));
+                $this->setSafe($node, ['all']);
             } else {
-                $this->setSafe($node, array());
+                $this->setSafe($node, []);
             }
         } elseif ($node instanceof Twig_Node_Expression_GetAttr && $node->getNode('node') instanceof Twig_Node_Expression_Name) {
             $name = $node->getNode('node')->getAttribute('name');
             if (in_array($name, $this->safeVars)) {
-                $this->setSafe($node, array('all'));
+                $this->setSafe($node, ['all']);
             } else {
-                $this->setSafe($node, array());
+                $this->setSafe($node, []);
             }
         } else {
-            $this->setSafe($node, array());
+            $this->setSafe($node, []);
         }
 
         return $node;
@@ -123,7 +123,7 @@ final class Twig_NodeVisitor_SafeAnalysis extends Twig_BaseNodeVisitor
     private function intersectSafe(array $a = null, array $b = null)
     {
         if (null === $a || null === $b) {
-            return array();
+            return [];
         }
 
         if (in_array('all', $a)) {
