@@ -17,7 +17,7 @@
  */
 class Twig_Parser
 {
-    private $stack = array();
+    private $stack = [];
     private $stream;
     private $parent;
     private $handlers;
@@ -29,7 +29,7 @@ class Twig_Parser
     private $env;
     private $importedSymbols;
     private $traits;
-    private $embeddedTemplates = array();
+    private $embeddedTemplates = [];
     private $varNameSalt = 0;
 
     public function __construct(Twig_Environment $env)
@@ -50,7 +50,7 @@ class Twig_Parser
 
         // tag handlers
         if (null === $this->handlers) {
-            $this->handlers = array();
+            $this->handlers = [];
             foreach ($this->env->getTokenParsers() as $handler) {
                 $handler->setParser($this);
 
@@ -69,12 +69,12 @@ class Twig_Parser
 
         $this->stream = $stream;
         $this->parent = null;
-        $this->blocks = array();
-        $this->macros = array();
-        $this->traits = array();
-        $this->blockStack = array();
-        $this->importedSymbols = array(array());
-        $this->embeddedTemplates = array();
+        $this->blocks = [];
+        $this->macros = [];
+        $this->traits = [];
+        $this->blockStack = [];
+        $this->importedSymbols = [[]];
+        $this->embeddedTemplates = [];
         $this->varNameSalt = 0;
 
         try {
@@ -95,7 +95,7 @@ class Twig_Parser
             throw $e;
         }
 
-        $node = new Twig_Node_Module(new Twig_Node_Body(array($body)), $this->parent, new Twig_Node($this->blocks), new Twig_Node($this->macros), new Twig_Node($this->traits), $this->embeddedTemplates, $stream->getSourceContext());
+        $node = new Twig_Node_Module(new Twig_Node_Body([$body]), $this->parent, new Twig_Node($this->blocks), new Twig_Node($this->macros), new Twig_Node($this->traits), $this->embeddedTemplates, $stream->getSourceContext());
 
         $traverser = new Twig_NodeTraverser($this->env, $this->visitors);
 
@@ -112,7 +112,7 @@ class Twig_Parser
     public function subparse($test, $dropNeedle = false)
     {
         $lineno = $this->getCurrentToken()->getLine();
-        $rv = array();
+        $rv = [];
         while (!$this->stream->isEOF()) {
             switch ($this->getCurrentToken()->getType()) {
                 case /* Twig_Token::TEXT_TYPE */ 0:
@@ -144,7 +144,7 @@ class Twig_Parser
                             return $rv[0];
                         }
 
-                        return new Twig_Node($rv, array(), $lineno);
+                        return new Twig_Node($rv, [], $lineno);
                     }
 
                     if (!isset($this->handlers[$token->getValue()])) {
@@ -180,7 +180,7 @@ class Twig_Parser
             return $rv[0];
         }
 
-        return new Twig_Node($rv, array(), $lineno);
+        return new Twig_Node($rv, [], $lineno);
     }
 
     public function getBlockStack()
@@ -215,7 +215,7 @@ class Twig_Parser
 
     public function setBlock($name, Twig_Node_Block $value)
     {
-        $this->blocks[$name] = new Twig_Node_Body(array($value), array(), $value->getTemplateLine());
+        $this->blocks[$name] = new Twig_Node_Body([$value], [], $value->getTemplateLine());
     }
 
     public function hasMacro($name)
@@ -252,7 +252,7 @@ class Twig_Parser
 
     public function addImportedSymbol($type, $alias, $name = null, Twig_Node_Expression $node = null)
     {
-        $this->importedSymbols[0][$type][$alias] = array('name' => $name, 'node' => $node);
+        $this->importedSymbols[0][$type][$alias] = ['name' => $name, 'node' => $node];
     }
 
     public function getImportedSymbol($type, $alias)
@@ -271,7 +271,7 @@ class Twig_Parser
 
     public function pushLocalScope()
     {
-        array_unshift($this->importedSymbols, array());
+        array_unshift($this->importedSymbols, []);
     }
 
     public function popLocalScope()
@@ -323,7 +323,11 @@ class Twig_Parser
             (!$node instanceof Twig_Node_Text && !$node instanceof Twig_Node_BlockReference && ($node instanceof Twig_NodeOutputInterface && !$node instanceof Twig_Node_Spaceless))
         ) {
             if (false !== strpos((string) $node, chr(0xEF).chr(0xBB).chr(0xBF))) {
-                throw new Twig_Error_Syntax('A template that extends another one cannot start with a byte order mark (BOM); it must be removed.', $node->getTemplateLine(), $this->stream->getSourceContext());
+                $t = substr($node->getAttribute('data'), 3);
+                if ('' === $t || ctype_space($t)) {
+                    // bypass empty nodes starting with a BOM
+                    return;
+                }
             }
 
             throw new Twig_Error_Syntax('A template that extends another one cannot include content outside Twig blocks. Did you forget to put the content inside a {% block %} tag?', $node->getTemplateLine(), $this->stream->getSourceContext());
@@ -346,6 +350,7 @@ class Twig_Parser
         if ($nested && $node instanceof Twig_Node_BlockReference) {
             //throw new Twig_Error_Syntax('A block definition cannot be nested under non-capturing nodes.', $node->getTemplateLine(), $this->stream->getSourceContext());
             @trigger_error(sprintf('Nesting a block definition under a non-capturing node in "%s" at line %d is deprecated since version 2.5.0 and will become a syntax error in 3.0.', $this->stream->getSourceContext()->getName(), $node->getTemplateLine()), E_USER_DEPRECATED);
+
             return;
         }
 
@@ -356,7 +361,7 @@ class Twig_Parser
 
         // here, $nested means "being at the root level of a child template"
         // we need to discard the wrapping "Twig_Node" for the "body" node
-        $nested = $nested || get_class($node) !== 'Twig_Node';
+        $nested = $nested || 'Twig_Node' !== get_class($node);
         foreach ($node as $k => $n) {
             if (null !== $n && null === $this->filterBodyNodes($n, $nested)) {
                 $node->removeNode($k);
