@@ -18,7 +18,7 @@ class Twig_Profiler_Node_EnterProfile extends Twig_Node
 {
     public function __construct($extensionName, $type, $name, $varName)
     {
-        parent::__construct(array(), array('extension_name' => $extensionName, 'name' => $name, 'type' => $type, 'var_name' => $varName));
+        parent::__construct([], ['extension_name' => $extensionName, 'name' => $name, 'type' => $type, 'var_name' => $varName]);
     }
 
     public function compile(Twig_Compiler $compiler)
