@@ -19,7 +19,7 @@ final class Twig_TokenParser_AutoEscape extends Twig_TokenParser
         $lineno = $token->getLine();
         $stream = $this->parser->getStream();
 
-        if ($stream->test(Twig_Token::BLOCK_END_TYPE)) {
+        if ($stream->test(/* Twig_Token::BLOCK_END_TYPE */ 3)) {
             $value = 'html';
         } else {
             $expr = $this->parser->getExpressionParser()->parseExpression();
@@ -29,9 +29,9 @@ final class Twig_TokenParser_AutoEscape extends Twig_TokenParser
             $value = $expr->getAttribute('value');
         }
 
-        $stream->expect(Twig_Token::BLOCK_END_TYPE);
-        $body = $this->parser->subparse(array($this, 'decideBlockEnd'), true);
-        $stream->expect(Twig_Token::BLOCK_END_TYPE);
+        $stream->expect(/* Twig_Token::BLOCK_END_TYPE */ 3);
+        $body = $this->parser->subparse([$this, 'decideBlockEnd'], true);
+        $stream->expect(/* Twig_Token::BLOCK_END_TYPE */ 3);
 
         return new Twig_Node_AutoEscape($value, $body, $lineno, $this->getTag());
     }
