@@ -22,22 +22,22 @@ final class Twig_TokenParser_Embed extends Twig_TokenParser_Include
 
         list($variables, $only, $ignoreMissing) = $this->parseArguments();
 
-        $parentToken = $fakeParentToken = new Twig_Token(Twig_Token::STRING_TYPE, '__parent__', $token->getLine());
+        $parentToken = $fakeParentToken = new Twig_Token(/* Twig_Token::STRING_TYPE */ 7, '__parent__', $token->getLine());
         if ($parent instanceof Twig_Node_Expression_Constant) {
-            $parentToken = new Twig_Token(Twig_Token::STRING_TYPE, $parent->getAttribute('value'), $token->getLine());
+            $parentToken = new Twig_Token(/* Twig_Token::STRING_TYPE */ 7, $parent->getAttribute('value'), $token->getLine());
         } elseif ($parent instanceof Twig_Node_Expression_Name) {
-            $parentToken = new Twig_Token(Twig_Token::NAME_TYPE, $parent->getAttribute('name'), $token->getLine());
+            $parentToken = new Twig_Token(/* Twig_Token::NAME_TYPE */ 5, $parent->getAttribute('name'), $token->getLine());
         }
 
         // inject a fake parent to make the parent() function work
-        $stream->injectTokens(array(
-            new Twig_Token(Twig_Token::BLOCK_START_TYPE, '', $token->getLine()),
-            new Twig_Token(Twig_Token::NAME_TYPE, 'extends', $token->getLine()),
+        $stream->injectTokens([
+            new Twig_Token(/* Twig_Token::BLOCK_START_TYPE */ 1, '', $token->getLine()),
+            new Twig_Token(/* Twig_Token::NAME_TYPE */ 5, 'extends', $token->getLine()),
             $parentToken,
-            new Twig_Token(Twig_Token::BLOCK_END_TYPE, '', $token->getLine()),
-        ));
+            new Twig_Token(/* Twig_Token::BLOCK_END_TYPE */ 3, '', $token->getLine()),
+        ]);
 
-        $module = $this->parser->parse($stream, array($this, 'decideBlockEnd'), true);
+        $module = $this->parser->parse($stream, [$this, 'decideBlockEnd'], true);
 
         // override the parent with the correct one
         if ($fakeParentToken === $parentToken) {
@@ -46,7 +46,7 @@ final class Twig_TokenParser_Embed extends Twig_TokenParser_Include
 
         $this->parser->embedTemplate($module);
 
-        $stream->expect(Twig_Token::BLOCK_END_TYPE);
+        $stream->expect(/* Twig_Token::BLOCK_END_TYPE */ 3);
 
         return new Twig_Node_Embed($module->getTemplateName(), $module->getAttribute('index'), $variables, $only, $ignoreMissing, $token->getLine(), $this->getTag());
     }
