@@ -28,23 +28,23 @@ final class Twig_TokenParser_For extends Twig_TokenParser
         $lineno = $token->getLine();
         $stream = $this->parser->getStream();
         $targets = $this->parser->getExpressionParser()->parseAssignmentExpression();
-        $stream->expect(Twig_Token::OPERATOR_TYPE, 'in');
+        $stream->expect(/* Twig_Token::OPERATOR_TYPE */ 8, 'in');
         $seq = $this->parser->getExpressionParser()->parseExpression();
 
         $ifexpr = null;
-        if ($stream->nextIf(Twig_Token::NAME_TYPE, 'if')) {
+        if ($stream->nextIf(/* Twig_Token::NAME_TYPE */ 5, 'if')) {
             $ifexpr = $this->parser->getExpressionParser()->parseExpression();
         }
 
-        $stream->expect(Twig_Token::BLOCK_END_TYPE);
-        $body = $this->parser->subparse(array($this, 'decideForFork'));
+        $stream->expect(/* Twig_Token::BLOCK_END_TYPE */ 3);
+        $body = $this->parser->subparse([$this, 'decideForFork']);
         if ('else' == $stream->next()->getValue()) {
-            $stream->expect(Twig_Token::BLOCK_END_TYPE);
-            $else = $this->parser->subparse(array($this, 'decideForEnd'), true);
+            $stream->expect(/* Twig_Token::BLOCK_END_TYPE */ 3);
+            $else = $this->parser->subparse([$this, 'decideForEnd'], true);
         } else {
             $else = null;
         }
-        $stream->expect(Twig_Token::BLOCK_END_TYPE);
+        $stream->expect(/* Twig_Token::BLOCK_END_TYPE */ 3);
 
         if (count($targets) > 1) {
             $keyTarget = $targets->getNode(0);
@@ -67,7 +67,7 @@ final class Twig_TokenParser_For extends Twig_TokenParser
 
     public function decideForFork(Twig_Token $token)
     {
-        return $token->test(array('else', 'endfor'));
+        return $token->test(['else', 'endfor']);
     }
 
     public function decideForEnd(Twig_Token $token)
@@ -97,7 +97,7 @@ final class Twig_TokenParser_For extends Twig_TokenParser
     {
         if ($node instanceof Twig_Node_Expression_GetAttr && $node->getNode('node') instanceof Twig_Node_Expression_Name && 'loop' == $node->getNode('node')->getAttribute('name')) {
             $attribute = $node->getNode('attribute');
-            if ($attribute instanceof Twig_Node_Expression_Constant && in_array($attribute->getAttribute('value'), array('length', 'revindex0', 'revindex', 'last'))) {
+            if ($attribute instanceof Twig_Node_Expression_Constant && in_array($attribute->getAttribute('value'), ['length', 'revindex0', 'revindex', 'last'])) {
                 throw new Twig_Error_Syntax(sprintf('The "loop.%s" variable is not defined when looping with a condition.', $attribute->getAttribute('value')), $node->getTemplateLine(), $stream->getSourceContext());
             }
         }
