@@ -21,7 +21,7 @@
  * {% block content %}{% endblock %}
  * </pre>
  *
- * @see http://www.twig-project.org/doc/templates.html#horizontal-reuse for details.
+ * @see https://twig.symfony.com/doc/templates.html#horizontal-reuse for details.
  */
 final class Twig_TokenParser_Use extends Twig_TokenParser
 {
@@ -34,7 +34,7 @@ final class Twig_TokenParser_Use extends Twig_TokenParser
             throw new Twig_Error_Syntax('The template references in a "use" statement must be a string.', $stream->getCurrent()->getLine(), $stream->getSourceContext());
         }
 
-        $targets = array();
+        $targets = [];
         if ($stream->nextIf('with')) {
             do {
                 $name = $stream->expect(/* Twig_Token::NAME_TYPE */ 5)->getValue();
@@ -54,7 +54,7 @@ final class Twig_TokenParser_Use extends Twig_TokenParser
 
         $stream->expect(/* Twig_Token::BLOCK_END_TYPE */ 3);
 
-        $this->parser->addTrait(new Twig_Node(array('template' => $template, 'targets' => new Twig_Node($targets))));
+        $this->parser->addTrait(new Twig_Node(['template' => $template, 'targets' => new Twig_Node($targets)]));
 
         return new Twig_Node();
     }
