@@ -22,16 +22,16 @@ final class Twig_TokenParser_With extends Twig_TokenParser
 
         $variables = null;
         $only = false;
-        if (!$stream->test(Twig_Token::BLOCK_END_TYPE)) {
+        if (!$stream->test(/* Twig_Token::BLOCK_END_TYPE */ 3)) {
             $variables = $this->parser->getExpressionParser()->parseExpression();
-            $only = $stream->nextIf(Twig_Token::NAME_TYPE, 'only');
+            $only = $stream->nextIf(/* Twig_Token::NAME_TYPE */ 5, 'only');
         }
 
-        $stream->expect(Twig_Token::BLOCK_END_TYPE);
+        $stream->expect(/* Twig_Token::BLOCK_END_TYPE */ 3);
 
-        $body = $this->parser->subparse(array($this, 'decideWithEnd'), true);
+        $body = $this->parser->subparse([$this, 'decideWithEnd'], true);
 
-        $stream->expect(Twig_Token::BLOCK_END_TYPE);
+        $stream->expect(/* Twig_Token::BLOCK_END_TYPE */ 3);
 
         return new Twig_Node_With($body, $variables, $only, $token->getLine(), $this->getTag());
     }
