@@ -14,7 +14,7 @@ class Twig_Tests_Loader_FilesystemTest extends \PHPUnit\Framework\TestCase
     public function testGetSourceContext()
     {
         $path = __DIR__.'/../Fixtures';
-        $loader = new Twig_Loader_Filesystem(array($path));
+        $loader = new Twig_Loader_Filesystem([$path]);
         $this->assertEquals('errors/index.html', $loader->getSourceContext('errors/index.html')->getName());
         $this->assertEquals(realpath($path.'/errors/index.html'), realpath($loader->getSourceContext('errors/index.html')->getPath()));
     }
@@ -24,7 +24,7 @@ class Twig_Tests_Loader_FilesystemTest extends \PHPUnit\Framework\TestCase
      */
     public function testSecurity($template)
     {
-        $loader = new Twig_Loader_Filesystem(array(__DIR__.'/../Fixtures'));
+        $loader = new Twig_Loader_Filesystem([__DIR__.'/../Fixtures']);
 
         try {
             $loader->getCacheKey($template);
@@ -36,27 +36,27 @@ class Twig_Tests_Loader_FilesystemTest extends \PHPUnit\Framework\TestCase
 
     public function getSecurityTests()
     {
-        return array(
-            array("AutoloaderTest\0.php"),
-            array('..\\AutoloaderTest.php'),
-            array('..\\\\\\AutoloaderTest.php'),
-            array('../AutoloaderTest.php'),
-            array('..////AutoloaderTest.php'),
-            array('./../AutoloaderTest.php'),
-            array('.\\..\\AutoloaderTest.php'),
-            array('././././././../AutoloaderTest.php'),
-            array('.\\./.\\./.\\./../AutoloaderTest.php'),
-            array('foo/../../AutoloaderTest.php'),
-            array('foo\\..\\..\\AutoloaderTest.php'),
-            array('foo/../bar/../../AutoloaderTest.php'),
-            array('foo/bar/../../../AutoloaderTest.php'),
-            array('filters/../../AutoloaderTest.php'),
-            array('filters//..//..//AutoloaderTest.php'),
-            array('filters\\..\\..\\AutoloaderTest.php'),
-            array('filters\\\\..\\\\..\\\\AutoloaderTest.php'),
-            array('filters\\//../\\/\\..\\AutoloaderTest.php'),
-            array('/../AutoloaderTest.php'),
-        );
+        return [
+            ["AutoloaderTest\0.php"],
+            ['..\\AutoloaderTest.php'],
+            ['..\\\\\\AutoloaderTest.php'],
+            ['../AutoloaderTest.php'],
+            ['..////AutoloaderTest.php'],
+            ['./../AutoloaderTest.php'],
+            ['.\\..\\AutoloaderTest.php'],
+            ['././././././../AutoloaderTest.php'],
+            ['.\\./.\\./.\\./../AutoloaderTest.php'],
+            ['foo/../../AutoloaderTest.php'],
+            ['foo\\..\\..\\AutoloaderTest.php'],
+            ['foo/../bar/../../AutoloaderTest.php'],
+            ['foo/bar/../../../AutoloaderTest.php'],
+            ['filters/../../AutoloaderTest.php'],
+            ['filters//..//..//AutoloaderTest.php'],
+            ['filters\\..\\..\\AutoloaderTest.php'],
+            ['filters\\\\..\\\\..\\\\AutoloaderTest.php'],
+            ['filters\\//../\\/\\..\\AutoloaderTest.php'],
+            ['/../AutoloaderTest.php'],
+        ];
     }
 
     /**
@@ -64,27 +64,27 @@ class Twig_Tests_Loader_FilesystemTest extends \PHPUnit\Framework\TestCase
      */
     public function testPaths($basePath, $cacheKey, $rootPath)
     {
-        $loader = new Twig_Loader_Filesystem(array($basePath.'/normal', $basePath.'/normal_bis'), $rootPath);
-        $loader->setPaths(array($basePath.'/named', $basePath.'/named_bis'), 'named');
+        $loader = new Twig_Loader_Filesystem([$basePath.'/normal', $basePath.'/normal_bis'], $rootPath);
+        $loader->setPaths([$basePath.'/named', $basePath.'/named_bis'], 'named');
         $loader->addPath($basePath.'/named_ter', 'named');
         $loader->addPath($basePath.'/normal_ter');
         $loader->prependPath($basePath.'/normal_final');
         $loader->prependPath($basePath.'/named/../named_quater', 'named');
         $loader->prependPath($basePath.'/named_final', 'named');
 
-        $this->assertEquals(array(
+        $this->assertEquals([
             $basePath.'/normal_final',
             $basePath.'/normal',
             $basePath.'/normal_bis',
             $basePath.'/normal_ter',
-        ), $loader->getPaths());
-        $this->assertEquals(array(
+        ], $loader->getPaths());
+        $this->assertEquals([
             $basePath.'/named_final',
             $basePath.'/named/../named_quater',
             $basePath.'/named',
             $basePath.'/named_bis',
             $basePath.'/named_ter',
-        ), $loader->getPaths('named'));
+        ], $loader->getPaths('named'));
 
         // do not use realpath here as it would make the test unuseful
         $this->assertEquals($cacheKey, str_replace('\\', '/', $loader->getCacheKey('@named/named_absolute.html')));
@@ -95,55 +95,55 @@ class Twig_Tests_Loader_FilesystemTest extends \PHPUnit\Framework\TestCase
 
     public function getBasePaths()
     {
-        return array(
-            array(
+        return [
+            [
                 __DIR__.'/Fixtures',
                 'test/Twig/Tests/Loader/Fixtures/named_quater/named_absolute.html',
                 null,
-            ),
-            array(
+            ],
+            [
                 __DIR__.'/Fixtures/../Fixtures',
                 'test/Twig/Tests/Loader/Fixtures/named_quater/named_absolute.html',
                 null,
-            ),
-            array(
+            ],
+            [
                 'test/Twig/Tests/Loader/Fixtures',
                 'test/Twig/Tests/Loader/Fixtures/named_quater/named_absolute.html',
                 getcwd(),
-            ),
-            array(
+            ],
+            [
                 'Fixtures',
                 'Fixtures/named_quater/named_absolute.html',
                 getcwd().'/test/Twig/Tests/Loader',
-            ),
-            array(
+            ],
+            [
                 'Fixtures',
                 'Fixtures/named_quater/named_absolute.html',
                 getcwd().'/test/../test/Twig/Tests/Loader',
-            ),
-        );
+            ],
+        ];
     }
 
     public function testEmptyConstructor()
     {
         $loader = new Twig_Loader_Filesystem();
-        $this->assertEquals(array(), $loader->getPaths());
+        $this->assertEquals([], $loader->getPaths());
     }
 
     public function testGetNamespaces()
     {
         $loader = new Twig_Loader_Filesystem(sys_get_temp_dir());
-        $this->assertEquals(array(Twig_Loader_Filesystem::MAIN_NAMESPACE), $loader->getNamespaces());
+        $this->assertEquals([Twig_Loader_Filesystem::MAIN_NAMESPACE], $loader->getNamespaces());
 
         $loader->addPath(sys_get_temp_dir(), 'named');
-        $this->assertEquals(array(Twig_Loader_Filesystem::MAIN_NAMESPACE, 'named'), $loader->getNamespaces());
+        $this->assertEquals([Twig_Loader_Filesystem::MAIN_NAMESPACE, 'named'], $loader->getNamespaces());
     }
 
     public function testFindTemplateExceptionNamespace()
     {
         $basePath = __DIR__.'/Fixtures';
 
-        $loader = new Twig_Loader_Filesystem(array($basePath.'/normal'));
+        $loader = new Twig_Loader_Filesystem([$basePath.'/normal']);
         $loader->addPath($basePath.'/named', 'named');
 
         try {
@@ -158,7 +158,7 @@ class Twig_Tests_Loader_FilesystemTest extends \PHPUnit\Framework\TestCase
     {
         $basePath = __DIR__.'/Fixtures';
 
-        $loader = new Twig_Loader_Filesystem(array($basePath.'/normal'));
+        $loader = new Twig_Loader_Filesystem([$basePath.'/normal']);
         $loader->addPath($basePath.'/named', 'named');
 
         // prime the cache for index.html in the named namespace
@@ -171,7 +171,7 @@ class Twig_Tests_Loader_FilesystemTest extends \PHPUnit\Framework\TestCase
 
     public function testLoadTemplateAndRenderBlockWithCache()
     {
-        $loader = new Twig_Loader_Filesystem(array());
+        $loader = new Twig_Loader_Filesystem([]);
         $loader->addPath(__DIR__.'/Fixtures/themes/theme2');
         $loader->addPath(__DIR__.'/Fixtures/themes/theme1');
         $loader->addPath(__DIR__.'/Fixtures/themes/theme1', 'default_theme');
@@ -179,20 +179,20 @@ class Twig_Tests_Loader_FilesystemTest extends \PHPUnit\Framework\TestCase
         $twig = new Twig_Environment($loader);
 
         $template = $twig->loadTemplate('blocks.html.twig');
-        $this->assertSame('block from theme 1', $template->renderBlock('b1', array()));
+        $this->assertSame('block from theme 1', $template->renderBlock('b1', []));
 
         $template = $twig->loadTemplate('blocks.html.twig');
-        $this->assertSame('block from theme 2', $template->renderBlock('b2', array()));
+        $this->assertSame('block from theme 2', $template->renderBlock('b2', []));
     }
 
     public function getArrayInheritanceTests()
     {
-        return array(
-            'valid array inheritance' => array('array_inheritance_valid_parent.html.twig'),
-            'array inheritance with null first template' => array('array_inheritance_null_parent.html.twig'),
-            'array inheritance with empty first template' => array('array_inheritance_empty_parent.html.twig'),
-            'array inheritance with non-existent first template' => array('array_inheritance_nonexistent_parent.html.twig'),
-        );
+        return [
+            'valid array inheritance' => ['array_inheritance_valid_parent.html.twig'],
+            'array inheritance with null first template' => ['array_inheritance_null_parent.html.twig'],
+            'array inheritance with empty first template' => ['array_inheritance_empty_parent.html.twig'],
+            'array inheritance with non-existent first template' => ['array_inheritance_nonexistent_parent.html.twig'],
+        ];
     }
 
     /**
@@ -202,18 +202,18 @@ class Twig_Tests_Loader_FilesystemTest extends \PHPUnit\Framework\TestCase
      */
     public function testArrayInheritance($templateName)
     {
-        $loader = new Twig_Loader_Filesystem(array());
+        $loader = new Twig_Loader_Filesystem([]);
         $loader->addPath(__DIR__.'/Fixtures/inheritance');
 
         $twig = new Twig_Environment($loader);
 
         $template = $twig->loadTemplate($templateName);
-        $this->assertSame('VALID Child', $template->renderBlock('body', array()));
+        $this->assertSame('VALID Child', $template->renderBlock('body', []));
     }
 
     public function testLoadTemplateFromPhar()
     {
-        $loader = new Twig_Loader_Filesystem(array());
+        $loader = new Twig_Loader_Filesystem([]);
         // phar-sample.phar was created with the following script:
         // $f = new Phar('phar-test.phar');
         // $f->addFromString('hello.twig', 'hello from phar');
@@ -223,7 +223,7 @@ class Twig_Tests_Loader_FilesystemTest extends \PHPUnit\Framework\TestCase
 
     public function testTemplateExistsAlwaysReturnsBool()
     {
-        $loader = new Twig_Loader_Filesystem(array());
+        $loader = new Twig_Loader_Filesystem([]);
         $this->assertFalse($loader->exists("foo\0.twig"));
         $this->assertFalse($loader->exists('../foo.twig'));
         $this->assertFalse($loader->exists('@foo'));
