@@ -11,34 +11,22 @@
 
 class Twig_Tests_Node_AutoEscapeTest extends Twig_Test_NodeTestCase
 {
-    /**
-     * @covers Twig_Node_AutoEscape::__construct
-     */
     public function testConstructor()
     {
-        $body = new Twig_Node(array(new Twig_Node_Text('foo', 1)));
+        $body = new Twig_Node([new Twig_Node_Text('foo', 1)]);
         $node = new Twig_Node_AutoEscape(true, $body, 1);
 
         $this->assertEquals($body, $node->getNode('body'));
         $this->assertTrue($node->getAttribute('value'));
     }
 
-    /**
-     * @covers Twig_Node_AutoEscape::compile
-     * @dataProvider getTests
-     */
-    public function testCompile($node, $source, $environment = null)
-    {
-        parent::testCompile($node, $source, $environment);
-    }
-
     public function getTests()
     {
-        $body = new Twig_Node(array(new Twig_Node_Text('foo', 1)));
+        $body = new Twig_Node([new Twig_Node_Text('foo', 1)]);
         $node = new Twig_Node_AutoEscape(true, $body, 1);
 
-        return array(
-            array($node, "// line 1\necho \"foo\";"),
-        );
+        return [
+            [$node, "// line 1\necho \"foo\";"],
+        ];
     }
 }
