@@ -11,9 +11,6 @@
 
 class Twig_Tests_Node_BlockReferenceTest extends Twig_Test_NodeTestCase
 {
-    /**
-     * @covers Twig_Node_BlockReference::__construct
-     */
     public function testConstructor()
     {
         $node = new Twig_Node_BlockReference('foo', 1);
@@ -21,23 +18,14 @@ class Twig_Tests_Node_BlockReferenceTest extends Twig_Test_NodeTestCase
         $this->assertEquals('foo', $node->getAttribute('name'));
     }
 
-    /**
-     * @covers Twig_Node_BlockReference::compile
-     * @dataProvider getTests
-     */
-    public function testCompile($node, $source, $environment = null)
-    {
-        parent::testCompile($node, $source, $environment);
-    }
-
     public function getTests()
     {
-        return array(
-            array(new Twig_Node_BlockReference('foo', 1), <<<EOF
+        return [
+            [new Twig_Node_BlockReference('foo', 1), <<<EOF
 // line 1
 \$this->displayBlock('foo', \$context, \$blocks);
 EOF
-            ),
-        );
+            ],
+        ];
     }
 }
