@@ -11,9 +11,6 @@
 
 class Twig_Tests_Node_BlockTest extends Twig_Test_NodeTestCase
 {
-    /**
-     * @covers Twig_Node_Block::__construct
-     */
     public function testConstructor()
     {
         $body = new Twig_Node_Text('foo', 1);
@@ -23,29 +20,20 @@ class Twig_Tests_Node_BlockTest extends Twig_Test_NodeTestCase
         $this->assertEquals('foo', $node->getAttribute('name'));
     }
 
-    /**
-     * @covers Twig_Node_Block::compile
-     * @dataProvider getTests
-     */
-    public function testCompile($node, $source, $environment = null)
-    {
-        parent::testCompile($node, $source, $environment);
-    }
-
     public function getTests()
     {
         $body = new Twig_Node_Text('foo', 1);
         $node = new Twig_Node_Block('foo', $body, 1);
 
-        return array(
-            array($node, <<<EOF
+        return [
+            [$node, <<<EOF
 // line 1
-public function block_foo(\$context, array \$blocks = array())
+public function block_foo(\$context, array \$blocks = [])
 {
     echo "foo";
 }
 EOF
-            ),
-        );
+            ],
+        ];
     }
 }
