@@ -27,8 +27,8 @@ class Twig_Tests_Node_Expression_Binary_DivTest extends Twig_Test_NodeTestCase
         $right = new Twig_Node_Expression_Constant(2, 1);
         $node = new Twig_Node_Expression_Binary_Div($left, $right, 1);
 
-        return array(
-            array($node, '(1 / 2)'),
-        );
+        return [
+            [$node, '(1 / 2)'],
+        ];
     }
 }
