@@ -11,9 +11,6 @@
 
 class Twig_Tests_Node_Expression_Unary_NotTest extends Twig_Test_NodeTestCase
 {
-    /**
-     * @covers Twig_Node_Expression_Unary_Not::__construct
-     */
     public function testConstructor()
     {
         $expr = new Twig_Node_Expression_Constant(1, 1);
@@ -22,23 +19,13 @@ class Twig_Tests_Node_Expression_Unary_NotTest extends Twig_Test_NodeTestCase
         $this->assertEquals($expr, $node->getNode('node'));
     }
 
-    /**
-     * @covers Twig_Node_Expression_Unary_Not::compile
-     * @covers Twig_Node_Expression_Unary_Not::operator
-     * @dataProvider getTests
-     */
-    public function testCompile($node, $source, $environment = null)
-    {
-        parent::testCompile($node, $source, $environment);
-    }
-
     public function getTests()
     {
         $node = new Twig_Node_Expression_Constant(1, 1);
         $node = new Twig_Node_Expression_Unary_Not($node, 1);
 
-        return array(
-            array($node, '(!1)'),
-        );
+        return [
+            [$node, '!1'],
+        ];
     }
 }
