@@ -11,9 +11,6 @@
 
 class Twig_Tests_Node_TextTest extends Twig_Test_NodeTestCase
 {
-    /**
-     * @covers Twig_Node_Text::__construct
-     */
     public function testConstructor()
     {
         $node = new Twig_Node_Text('foo', 1);
@@ -21,19 +18,10 @@ class Twig_Tests_Node_TextTest extends Twig_Test_NodeTestCase
         $this->assertEquals('foo', $node->getAttribute('data'));
     }
 
-    /**
-     * @covers Twig_Node_Text::compile
-     * @dataProvider getTests
-     */
-    public function testCompile($node, $source, $environment = null)
-    {
-        parent::testCompile($node, $source, $environment);
-    }
-
     public function getTests()
     {
-        $tests = array();
-        $tests[] = array(new Twig_Node_Text('foo', 1), "// line 1\necho \"foo\";");
+        $tests = [];
+        $tests[] = [new Twig_Node_Text('foo', 1), "// line 1\necho \"foo\";"];
 
         return $tests;
     }
