@@ -15,8 +15,8 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
      */
     public function testDisplayBlocksAcceptTemplateOnlyAsBlocks()
     {
-        $template = $this->getMockForAbstractClass('Twig_Template', array(), '', false);
-        $template->displayBlock('foo', array(), array('foo' => array(new stdClass(), 'foo')));
+        $template = $this->getMockForAbstractClass('Twig_Template', [], '', false);
+        $template->displayBlock('foo', [], ['foo' => [new stdClass(), 'foo']]);
     }
 
     /**
@@ -24,19 +24,19 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
      */
     public function testGetAttributeExceptions($template, $message)
     {
-        $templates = array('index' => $template);
-        $env = new Twig_Environment(new Twig_Loader_Array($templates), array('strict_variables' => true));
+        $templates = ['index' => $template];
+        $env = new Twig_Environment(new Twig_Loader_Array($templates), ['strict_variables' => true]);
         $template = $env->loadTemplate('index');
 
-        $context = array(
+        $context = [
             'string' => 'foo',
             'null' => null,
-            'empty_array' => array(),
-            'array' => array('foo' => 'foo'),
+            'empty_array' => [],
+            'array' => ['foo' => 'foo'],
             'array_access' => new Twig_TemplateArrayAccessObject(),
             'magic_exception' => new Twig_TemplateMagicPropertyObjectWithException(),
             'object' => new stdClass(),
-        );
+        ];
 
         try {
             $template->render($context);
@@ -48,25 +48,25 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
 
     public function getAttributeExceptions()
     {
-        return array(
-            array('{{ string["a"] }}', 'Impossible to access a key ("a") on a string variable ("foo") in "%s" at line 1.'),
-            array('{{ null["a"] }}', 'Impossible to access a key ("a") on a null variable in "%s" at line 1.'),
-            array('{{ empty_array["a"] }}', 'Key "a" does not exist as the array is empty in "%s" at line 1.'),
-            array('{{ array["a"] }}', 'Key "a" for array with keys "foo" does not exist in "%s" at line 1.'),
-            array('{{ array_access["a"] }}', 'Key "a" in object with ArrayAccess of class "Twig_TemplateArrayAccessObject" does not exist in "%s" at line 1.'),
-            array('{{ string.a }}', 'Impossible to access an attribute ("a") on a string variable ("foo") in "%s" at line 1.'),
-            array('{{ string.a() }}', 'Impossible to invoke a method ("a") on a string variable ("foo") in "%s" at line 1.'),
-            array('{{ null.a }}', 'Impossible to access an attribute ("a") on a null variable in "%s" at line 1.'),
-            array('{{ null.a() }}', 'Impossible to invoke a method ("a") on a null variable in "%s" at line 1.'),
-            array('{{ array.a() }}', 'Impossible to invoke a method ("a") on an array in "%s" at line 1.'),
-            array('{{ empty_array.a }}', 'Key "a" does not exist as the array is empty in "%s" at line 1.'),
-            array('{{ array.a }}', 'Key "a" for array with keys "foo" does not exist in "%s" at line 1.'),
-            array('{{ attribute(array, -10) }}', 'Key "-10" for array with keys "foo" does not exist in "%s" at line 1.'),
-            array('{{ array_access.a }}', 'Neither the property "a" nor one of the methods "a()", "geta()"/"isa()"/"hasa()" or "__call()" exist and have public access in class "Twig_TemplateArrayAccessObject" in "%s" at line 1.'),
-            array('{% from _self import foo %}{% macro foo(obj) %}{{ obj.missing_method() }}{% endmacro %}{{ foo(array_access) }}', 'Neither the property "missing_method" nor one of the methods "missing_method()", "getmissing_method()"/"ismissing_method()"/"hasmissing_method()" or "__call()" exist and have public access in class "Twig_TemplateArrayAccessObject" in "%s" at line 1.'),
-            array('{{ magic_exception.test }}', 'An exception has been thrown during the rendering of a template ("Hey! Don\'t try to isset me!") in "%s" at line 1.'),
-            array('{{ object["a"] }}', 'Impossible to access a key "a" on an object of class "stdClass" that does not implement ArrayAccess interface in "%s" at line 1.'),
-        );
+        return [
+            ['{{ string["a"] }}', 'Impossible to access a key ("a") on a string variable ("foo") in "%s" at line 1.'],
+            ['{{ null["a"] }}', 'Impossible to access a key ("a") on a null variable in "%s" at line 1.'],
+            ['{{ empty_array["a"] }}', 'Key "a" does not exist as the array is empty in "%s" at line 1.'],
+            ['{{ array["a"] }}', 'Key "a" for array with keys "foo" does not exist in "%s" at line 1.'],
+            ['{{ array_access["a"] }}', 'Key "a" in object with ArrayAccess of class "Twig_TemplateArrayAccessObject" does not exist in "%s" at line 1.'],
+            ['{{ string.a }}', 'Impossible to access an attribute ("a") on a string variable ("foo") in "%s" at line 1.'],
+            ['{{ string.a() }}', 'Impossible to invoke a method ("a") on a string variable ("foo") in "%s" at line 1.'],
+            ['{{ null.a }}', 'Impossible to access an attribute ("a") on a null variable in "%s" at line 1.'],
+            ['{{ null.a() }}', 'Impossible to invoke a method ("a") on a null variable in "%s" at line 1.'],
+            ['{{ array.a() }}', 'Impossible to invoke a method ("a") on an array in "%s" at line 1.'],
+            ['{{ empty_array.a }}', 'Key "a" does not exist as the array is empty in "%s" at line 1.'],
+            ['{{ array.a }}', 'Key "a" for array with keys "foo" does not exist in "%s" at line 1.'],
+            ['{{ attribute(array, -10) }}', 'Key "-10" for array with keys "foo" does not exist in "%s" at line 1.'],
+            ['{{ array_access.a }}', 'Neither the property "a" nor one of the methods "a()", "geta()"/"isa()"/"hasa()" or "__call()" exist and have public access in class "Twig_TemplateArrayAccessObject" in "%s" at line 1.'],
+            ['{% from _self import foo %}{% macro foo(obj) %}{{ obj.missing_method() }}{% endmacro %}{{ foo(array_access) }}', 'Neither the property "missing_method" nor one of the methods "missing_method()", "getmissing_method()"/"ismissing_method()"/"hasmissing_method()" or "__call()" exist and have public access in class "Twig_TemplateArrayAccessObject" in "%s" at line 1.'],
+            ['{{ magic_exception.test }}', 'An exception has been thrown during the rendering of a template ("Hey! Don\'t try to isset me!") in "%s" at line 1.'],
+            ['{{ object["a"] }}', 'Impossible to access a key "a" on an object of class "stdClass" that does not implement ArrayAccess interface in "%s" at line 1.'],
+        ];
     }
 
     /**
@@ -75,12 +75,12 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
     public function testGetAttributeWithSandbox($object, $item, $allowed)
     {
         $twig = new Twig_Environment($this->getMockBuilder('Twig_LoaderInterface')->getMock());
-        $policy = new Twig_Sandbox_SecurityPolicy(array(), array(), array(/*method*/), array(/*prop*/), array());
+        $policy = new Twig_Sandbox_SecurityPolicy([], [], [/*method*/], [/*prop*/], []);
         $twig->addExtension(new Twig_Extension_Sandbox($policy, !$allowed));
         $template = new Twig_TemplateTest($twig);
 
         try {
-            twig_get_attribute($twig, $template->getSourceContext(), $object, $item, array(), 'any', false, false, true);
+            twig_get_attribute($twig, $template->getSourceContext(), $object, $item, [], 'any', false, false, true);
 
             if (!$allowed) {
                 $this->fail();
@@ -100,12 +100,12 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
 
     public function getGetAttributeWithSandbox()
     {
-        return array(
-            array(new Twig_TemplatePropertyObject(), 'defined', false),
-            array(new Twig_TemplatePropertyObject(), 'defined', true),
-            array(new Twig_TemplateMethodObject(), 'defined', false),
-            array(new Twig_TemplateMethodObject(), 'defined', true),
-        );
+        return [
+            [new Twig_TemplatePropertyObject(), 'defined', false],
+            [new Twig_TemplatePropertyObject(), 'defined', true],
+            [new Twig_TemplateMethodObject(), 'defined', false],
+            [new Twig_TemplateMethodObject(), 'defined', true],
+        ];
     }
 
     /**
@@ -117,7 +117,7 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
         $twig = new Twig_Environment($this->getMockBuilder('Twig_LoaderInterface')->getMock());
         $template = new Twig_TemplateTest($twig, 'index.twig');
         try {
-            $template->renderBlock('unknown', array());
+            $template->renderBlock('unknown', []);
         } catch (\Exception $e) {
             ob_end_clean();
 
@@ -133,7 +133,7 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
     {
         $twig = new Twig_Environment($this->getMockBuilder('Twig_LoaderInterface')->getMock());
         $template = new Twig_TemplateTest($twig, 'index.twig');
-        $template->displayBlock('unknown', array());
+        $template->displayBlock('unknown', []);
     }
 
     /**
@@ -144,7 +144,7 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
     {
         $twig = new Twig_Environment($this->getMockBuilder('Twig_LoaderInterface')->getMock());
         $template = new Twig_TemplateTest($twig, 'parent.twig');
-        $template->displayBlock('foo', array(), array('foo' => array(new Twig_TemplateTest($twig, 'index.twig'), 'block_foo')), false);
+        $template->displayBlock('foo', [], ['foo' => [new Twig_TemplateTest($twig, 'index.twig'), 'block_foo']], false);
     }
 
     public function testGetAttributeOnArrayWithConfusableKey()
@@ -152,7 +152,7 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
         $twig = new Twig_Environment($this->getMockBuilder('Twig_LoaderInterface')->getMock());
         $template = new Twig_TemplateTest($twig);
 
-        $array = array('Zero', 'One', -1 => 'MinusOne', '' => 'EmptyString', '1.5' => 'FloatButString', '01' => 'IntegerButStringWithLeadingZeros');
+        $array = ['Zero', 'One', -1 => 'MinusOne', '' => 'EmptyString', '1.5' => 'FloatButString', '01' => 'IntegerButStringWithLeadingZeros'];
 
         $this->assertSame('Zero', $array[false]);
         $this->assertSame('One', $array[true]);
@@ -189,7 +189,7 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
      */
     public function testGetAttributeStrict($defined, $value, $object, $item, $arguments, $type, $exceptionMessage = null)
     {
-        $twig = new Twig_Environment($this->getMockBuilder('Twig_LoaderInterface')->getMock(), array('strict_variables' => true));
+        $twig = new Twig_Environment($this->getMockBuilder('Twig_LoaderInterface')->getMock(), ['strict_variables' => true]);
         $template = new Twig_TemplateTest($twig);
 
         if ($defined) {
@@ -223,7 +223,7 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
      */
     public function testGetAttributeDefinedStrict($defined, $value, $object, $item, $arguments, $type)
     {
-        $twig = new Twig_Environment($this->getMockBuilder('Twig_LoaderInterface')->getMock(), array('strict_variables' => true));
+        $twig = new Twig_Environment($this->getMockBuilder('Twig_LoaderInterface')->getMock(), ['strict_variables' => true]);
         $template = new Twig_TemplateTest($twig);
 
         $this->assertEquals($defined, twig_get_attribute($twig, $template->getSourceContext(), $object, $item, $arguments, $type, true));
@@ -241,7 +241,7 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
 
     public function getGetAttributeTests()
     {
-        $array = array(
+        $array = [
             'defined' => 'defined',
             'zero' => 0,
             'null' => null,
@@ -252,9 +252,10 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
             'baf' => 'baf',
             '09' => '09',
             '+4' => '+4',
-        );
+        ];
 
         $objectArray = new Twig_TemplateArrayAccessObject();
+        $arrayObject = new ArrayObject($array);
         $stdObject = (object) $array;
         $magicPropertyObject = new Twig_TemplateMagicPropertyObject();
         $propertyObject = new Twig_TemplatePropertyObject();
@@ -268,36 +269,37 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
         $methodType = Twig_Template::METHOD_CALL;
         $arrayType = Twig_Template::ARRAY_CALL;
 
-        $basicTests = array(
+        $basicTests = [
             // array(defined, value, property to fetch)
-            array(true,  'defined', 'defined'),
-            array(false, null,      'undefined'),
-            array(false, null,      'protected'),
-            array(true,  0,         'zero'),
-            array(true,  1,         1),
-            array(true,  1,         1.0),
-            array(true,  null,      'null'),
-            array(true,  true,      'bar'),
-            array(true,  true,      'foo'),
-            array(true,  'baz',     'baz'),
-            array(true,  'baf',     'baf'),
-            array(true,  '09',      '09'),
-            array(true,  '+4',      '+4'),
-        );
-        $testObjects = array(
+            [true,  'defined', 'defined'],
+            [false, null,      'undefined'],
+            [false, null,      'protected'],
+            [true,  0,         'zero'],
+            [true,  1,         1],
+            [true,  1,         1.0],
+            [true,  null,      'null'],
+            [true,  true,      'bar'],
+            [true,  true,      'foo'],
+            [true,  'baz',     'baz'],
+            [true,  'baf',     'baf'],
+            [true,  '09',      '09'],
+            [true,  '+4',      '+4'],
+        ];
+        $testObjects = [
             // array(object, type of fetch)
-            array($array,               $arrayType),
-            array($objectArray,         $arrayType),
-            array($stdObject,           $anyType),
-            array($magicPropertyObject, $anyType),
-            array($methodObject,        $methodType),
-            array($methodObject,        $anyType),
-            array($propertyObject,      $anyType),
-            array($propertyObject1,     $anyType),
-            array($propertyObject2,     $anyType),
-        );
+            [$array,               $arrayType],
+            [$objectArray,         $arrayType],
+            [$arrayObject,         $anyType],
+            [$stdObject,           $anyType],
+            [$magicPropertyObject, $anyType],
+            [$methodObject,        $methodType],
+            [$methodObject,        $anyType],
+            [$propertyObject,      $anyType],
+            [$propertyObject1,     $anyType],
+            [$propertyObject2,     $anyType],
+        ];
 
-        $tests = array();
+        $tests = [];
         foreach ($testObjects as $testObject) {
             foreach ($basicTests as $test) {
                 // properties cannot be numbers
@@ -309,27 +311,27 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
                     continue;
                 }
 
-                $tests[] = array($test[0], $test[1], $testObject[0], $test[2], array(), $testObject[1]);
+                $tests[] = [$test[0], $test[1], $testObject[0], $test[2], [], $testObject[1]];
             }
         }
 
         // additional properties tests
-        $tests = array_merge($tests, array(
-            array(true, null, $propertyObject3, 'foo', array(), $anyType),
-        ));
+        $tests = array_merge($tests, [
+            [true, null, $propertyObject3, 'foo', [], $anyType],
+        ]);
 
         // additional method tests
-        $tests = array_merge($tests, array(
-            array(true, 'defined', $methodObject, 'defined',    array(), $methodType),
-            array(true, 'defined', $methodObject, 'DEFINED',    array(), $methodType),
-            array(true, 'defined', $methodObject, 'getDefined', array(), $methodType),
-            array(true, 'defined', $methodObject, 'GETDEFINED', array(), $methodType),
-            array(true, 'static',  $methodObject, 'static',     array(), $methodType),
-            array(true, 'static',  $methodObject, 'getStatic',  array(), $methodType),
+        $tests = array_merge($tests, [
+            [true, 'defined', $methodObject, 'defined',    [], $methodType],
+            [true, 'defined', $methodObject, 'DEFINED',    [], $methodType],
+            [true, 'defined', $methodObject, 'getDefined', [], $methodType],
+            [true, 'defined', $methodObject, 'GETDEFINED', [], $methodType],
+            [true, 'static',  $methodObject, 'static',     [], $methodType],
+            [true, 'static',  $methodObject, 'getStatic',  [], $methodType],
 
-            array(true, '__call_undefined', $magicMethodObject, 'undefined', array(), $methodType),
-            array(true, '__call_UNDEFINED', $magicMethodObject, 'UNDEFINED', array(), $methodType),
-        ));
+            [true, '__call_undefined', $magicMethodObject, 'undefined', [], $methodType],
+            [true, '__call_UNDEFINED', $magicMethodObject, 'UNDEFINED', [], $methodType],
+        ]);
 
         // add the same tests for the any type
         foreach ($tests as $test) {
@@ -342,28 +344,33 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
         $methodAndPropObject = new Twig_TemplateMethodAndPropObject();
 
         // additional method tests
-        $tests = array_merge($tests, array(
-            array(true, 'a', $methodAndPropObject, 'a', array(), $anyType),
-            array(true, 'a', $methodAndPropObject, 'a', array(), $methodType),
-            array(false, null, $methodAndPropObject, 'a', array(), $arrayType),
+        $tests = array_merge($tests, [
+            [true, 'a', $methodAndPropObject, 'a', [], $anyType],
+            [true, 'a', $methodAndPropObject, 'a', [], $methodType],
+            [false, null, $methodAndPropObject, 'a', [], $arrayType],
 
-            array(true, 'b_prop', $methodAndPropObject, 'b', array(), $anyType),
-            array(true, 'b', $methodAndPropObject, 'B', array(), $anyType),
-            array(true, 'b', $methodAndPropObject, 'b', array(), $methodType),
-            array(true, 'b', $methodAndPropObject, 'B', array(), $methodType),
-            array(false, null, $methodAndPropObject, 'b', array(), $arrayType),
+            [true, 'b_prop', $methodAndPropObject, 'b', [], $anyType],
+            [true, 'b', $methodAndPropObject, 'B', [], $anyType],
+            [true, 'b', $methodAndPropObject, 'b', [], $methodType],
+            [true, 'b', $methodAndPropObject, 'B', [], $methodType],
+            [false, null, $methodAndPropObject, 'b', [], $arrayType],
 
-            array(false, null, $methodAndPropObject, 'c', array(), $anyType),
-            array(false, null, $methodAndPropObject, 'c', array(), $methodType),
-            array(false, null, $methodAndPropObject, 'c', array(), $arrayType),
-        ));
+            [false, null, $methodAndPropObject, 'c', [], $anyType],
+            [false, null, $methodAndPropObject, 'c', [], $methodType],
+            [false, null, $methodAndPropObject, 'c', [], $arrayType],
+        ]);
+
+        $arrayAccess = new Twig_TemplateArrayAccess();
+        $tests = array_merge($tests, [
+            [true, ['foo' => 'bar'], $arrayAccess, 'vars', [], $anyType],
+        ]);
 
         // tests when input is not an array or object
-        $tests = array_merge($tests, array(
-            array(false, null, 42, 'a', array(), $anyType, 'Impossible to access an attribute ("a") on a integer variable ("42") in "index.twig".'),
-            array(false, null, 'string', 'a', array(), $anyType, 'Impossible to access an attribute ("a") on a string variable ("string") in "index.twig".'),
-            array(false, null, array(), 'a', array(), $anyType, 'Key "a" does not exist as the array is empty in "index.twig".'),
-        ));
+        $tests = array_merge($tests, [
+            [false, null, 42, 'a', [], $anyType, 'Impossible to access an attribute ("a") on a integer variable ("42") in "index.twig".'],
+            [false, null, 'string', 'a', [], $anyType, 'Impossible to access an attribute ("a") on a string variable ("string") in "index.twig".'],
+            [false, null, [], 'a', [], $anyType, 'Key "a" does not exist as the array is empty in "index.twig".'],
+        ]);
 
         return $tests;
     }
@@ -373,9 +380,9 @@ class Twig_Tests_TemplateTest extends \PHPUnit\Framework\TestCase
      */
     public function testGetIsMethods()
     {
-        $twig = new Twig_Environment($this->getMockBuilder('Twig_LoaderInterface')->getMock(), array('strict_variables' => true));
+        $twig = new Twig_Environment($this->getMockBuilder('Twig_LoaderInterface')->getMock(), ['strict_variables' => true]);
         $getIsObject = new Twig_TemplateGetIsMethods();
-        $template = new Twig_TemplateTest($twig, array('strict_variables' => true));
+        $template = new Twig_TemplateTest($twig, ['strict_variables' => true]);
         // first time should not create a cache for "get"
         $this->assertNull(twig_get_attribute($twig, $template->getSourceContext(), $getIsObject, 'get'));
         // 0 should be in the method cache now, so this should fail
@@ -420,7 +427,7 @@ class Twig_TemplateTest extends Twig_Template
 
     public function getDebugInfo()
     {
-        return array();
+        return [];
     }
 
     protected function doGetParent(array $context)
@@ -428,11 +435,11 @@ class Twig_TemplateTest extends Twig_Template
         return false;
     }
 
-    protected function doDisplay(array $context, array $blocks = array())
+    protected function doDisplay(array $context, array $blocks = [])
     {
     }
 
-    public function block_name($context, array $blocks = array())
+    public function block_name($context, array $blocks = [])
     {
     }
 }
@@ -441,7 +448,7 @@ class Twig_TemplateArrayAccessObject implements ArrayAccess
 {
     protected $protected = 'protected';
 
-    public $attributes = array(
+    public $attributes = [
         'defined' => 'defined',
         'zero' => 0,
         'null' => null,
@@ -452,7 +459,7 @@ class Twig_TemplateArrayAccessObject implements ArrayAccess
         'baf' => 'baf',
         '09' => '09',
         '+4' => '+4',
-    );
+    ];
 
     public function offsetExists($name)
     {
@@ -477,7 +484,7 @@ class Twig_TemplateMagicPropertyObject
 {
     public $defined = 'defined';
 
-    public $attributes = array(
+    public $attributes = [
         'zero' => 0,
         'null' => null,
         '1' => 1,
@@ -487,7 +494,7 @@ class Twig_TemplateMagicPropertyObject
         'baf' => 'baf',
         '09' => '09',
         '+4' => '+4',
-    );
+    ];
 
     protected $protected = 'protected';
 
@@ -527,19 +534,21 @@ class Twig_TemplatePropertyObjectAndIterator extends Twig_TemplatePropertyObject
 {
     public function getIterator()
     {
-        return new ArrayIterator(array('foo', 'bar'));
+        return new ArrayIterator(['foo', 'bar']);
     }
 }
 
 class Twig_TemplatePropertyObjectAndArrayAccess extends Twig_TemplatePropertyObject implements ArrayAccess
 {
-    private $data = array(
+    private $data = [
         'defined' => 'defined',
         'zero' => 0,
         'null' => null,
         'bar' => true,
+        'foo' => true,
         'baz' => 'baz',
-    );
+        'baf' => 'baf',
+    ];
 
     public function offsetExists($offset)
     {
@@ -682,6 +691,34 @@ class Twig_TemplateMethodAndPropObject
     }
 }
 
+class Twig_TemplateArrayAccess implements ArrayAccess
+{
+    public $vars = [
+        'foo' => 'bar',
+    ];
+    private $children = [];
+
+    public function offsetExists($offset)
+    {
+        return array_key_exists($offset, $this->children);
+    }
+
+    public function offsetGet($offset)
+    {
+        return $this->children[$offset];
+    }
+
+    public function offsetSet($offset, $value)
+    {
+        $this->children[$offset] = $value;
+    }
+
+    public function offsetUnset($offset)
+    {
+        unset($this->children[$offset]);
+    }
+}
+
 class Twig_TemplateMagicMethodObject
 {
     public function __call($method, $arguments)
